@@ -1,6 +1,6 @@
 package File::Trash::Undoable;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 use Log::Any '$log';
@@ -8,7 +8,7 @@ use Log::Any '$log';
 use File::Trash::FreeDesktop;
 use SHARYANTO::File::Util qw(l_abs_path);
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 our %SPEC;
 
@@ -234,7 +234,7 @@ File::Trash::Undoable - Trash files (with undo support)
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -265,20 +265,22 @@ support per-filesystem trash (everything goes into home trash).
 
 =back
 
-=head1 DESCRIPTION
+=head1 AUTHOR
 
+Steven Haryanto <stevenharyanto@gmail.com>
 
-This module has L<Rinci> metadata.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Steven Haryanto.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 empty_trash() -> [status, msg, result, meta]
 
-Empty trash.
-
 No arguments.
 
 Return value:
@@ -287,7 +289,13 @@ Returns an enveloped result (an array). First element (status) is an integer con
 
 =head2 list_trash_contents() -> [status, msg, result, meta]
 
-List contents of trash directory.
+No arguments.
+
+Return value:
+
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
+=head2 trash() -> [status, msg, result, meta]
 
 No arguments.
 
@@ -295,168 +303,21 @@ Return value:
 
 Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
 
-=head2 trash(%args) -> [status, msg, result, meta]
+=head2 trash_files() -> [status, msg, result, meta]
 
-Trash a file.
-
-Fixed state: path does not exist.
-
-Fixable state: path exists.
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<path>* => I<str>
-
-=item * B<suffix> => I<str>
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
+No arguments.
 
 Return value:
 
 Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
 
-=head2 trash_files(%args) -> [status, msg, result, meta]
+=head2 untrash() -> [status, msg, result, meta]
 
-Trash files (with undo support).
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<files>* => I<array>
-
-Files/dirs to delete.
-
-Files must exist.
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
+No arguments.
 
 Return value:
 
 Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
 
-=head2 untrash(%args) -> [status, msg, result, meta]
-
-Untrash a file.
-
-Fixed state: path exists.
-
-Fixable state: Path does not exist (and exists in trash, and if suffix is
-specified, has the same suffix).
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<path>* => I<str>
-
-=item * B<suffix> => I<str>
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
-
-Return value:
-
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
-
-=head1 AUTHOR
-
-Steven Haryanto <stevenharyanto@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Steven Haryanto.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
